@@ -248,8 +248,8 @@ type Field struct {
 // env is nil or empty, it is interpreted as an empty set of variables.
 // In case of duplicate environment variables, the last one in the list
 // takes precedence.
-func Load(ctx context.Context, wd string, env []string, patterns []string) (*Info, []error) {
-	pkgs, errs := load(ctx, wd, env, patterns)
+func Load(ctx context.Context, wd string, env []string, tags string, patterns []string) (*Info, []error) {
+	pkgs, errs := load(ctx, wd, env, tags, patterns)
 	if len(errs) > 0 {
 		return nil, errs
 	}
@@ -349,7 +349,7 @@ func Load(ctx context.Context, wd string, env []string, patterns []string) (*Inf
 // env is nil or empty, it is interpreted as an empty set of variables.
 // In case of duplicate environment variables, the last one in the list
 // takes precedence.
-func load(ctx context.Context, wd string, env []string, patterns []string) ([]*packages.Package, []error) {
+func load(ctx context.Context, wd string, env []string, tags string, patterns []string) ([]*packages.Package, []error) {
 	cfg := &packages.Config{
 		Context:    ctx,
 		Mode:       packages.LoadAllSyntax,
@@ -358,6 +358,9 @@ func load(ctx context.Context, wd string, env []string, patterns []string) ([]*p
 		BuildFlags: []string{"-tags=wireinject"},
 		// TODO(light): Use ParseFile to skip function bodies and comments in indirect packages.
 	}
+	if len(tags) > 0 {
+		cfg.BuildFlags[0] += " " + tags
+	}
 	escaped := make([]string, len(patterns))
 	for i := range patterns {
 		escaped[i] = "pattern=" + patterns[i]
@@ -529,7 +532,14 @@ func (oc *objectCache) processExpr(info *types.Info, pkgPath string, expr ast.Ex
 	}
 	if call, ok := expr.(*ast.CallExpr); ok {
 		fnObj := qualifiedIdentObject(info, call.Fun)
-		if fnObj == nil || !isWireImport(fnObj.Pkg().Path()) {
+		if fnObj == nil {
+			return nil, []error{notePosition(exprPos, errors.New("unknown pattern fnObj nil"))}
+		}
+		pkg := fnObj.Pkg()
+		if pkg == nil {
+			return nil, []error{notePosition(exprPos, fmt.Errorf("unknown pattern - pkg in fnObj is nil - %s", fnObj))}
+		}
+		if !isWireImport(pkg.Path()) {
 			return nil, []error{notePosition(exprPos, errors.New("unknown pattern"))}
 		}
 		switch fnObj.Name() {
