@@ -65,6 +65,7 @@ type GenerateOptions struct {
 	// Header will be inserted at the start of each generated file.
 	Header           []byte
 	PrefixOutputFile string
+	Tags             string
 }
 
 // Generate performs dependency injection for the packages that match the given
@@ -83,7 +84,7 @@ func Generate(ctx context.Context, wd string, env []string, patterns []string, o
 	if opts == nil {
 		opts = &GenerateOptions{}
 	}
-	pkgs, errs := load(ctx, wd, env, patterns)
+	pkgs, errs := load(ctx, wd, env, opts.Tags, patterns)
 	if len(errs) > 0 {
 		return nil, errs
 	}
@@ -103,7 +104,7 @@ func Generate(ctx context.Context, wd string, env []string, patterns []string, o
 			continue
 		}
 		copyNonInjectorDecls(g, injectorFiles, pkg.TypesInfo)
-		goSrc := g.frame()
+		goSrc := g.frame(opts.Tags)
 		if len(opts.Header) > 0 {
 			goSrc = append(opts.Header, goSrc...)
 		}
@@ -179,7 +180,7 @@ func generateInjectors(g *gen, pkg *packages.Package) (injectorFiles []*ast.File
 				ec.add(notePositionAll(g.pkg.Fset.Position(fn.Pos()), errs)...)
 				continue
 			}
-			if errs := g.inject(fn.Pos(), fn.Name.Name, sig, set); len(errs) > 0 {
+			if errs := g.inject(fn.Pos(), fn.Name.Name, sig, set, fn.Doc); len(errs) > 0 {
 				ec.add(errs...)
 				continue
 			}
@@ -257,13 +258,16 @@ func newGen(pkg *packages.Package) *gen {
 }
 
 // frame bakes the built up source body into an unformatted Go source file.
-func (g *gen) frame() []byte {
+func (g *gen) frame(tags string) []byte {
 	if g.buf.Len() == 0 {
 		return nil
 	}
 	var buf bytes.Buffer
+	if len(tags) > 0 {
+		tags = fmt.Sprintf(" gen -tags \"%s\"", tags)
+	}
 	buf.WriteString("// Code generated by Wire. DO NOT EDIT.\n\n")
-	buf.WriteString("//go:generate wire\n")
+	buf.WriteString("//go:generate go run github.com/google/wire/cmd/wire" + tags + "\n")
 	buf.WriteString("//+build !wireinject\n\n")
 	buf.WriteString("package ")
 	buf.WriteString(g.pkg.Name)
@@ -304,7 +308,7 @@ func (g *gen) frame() []byte {
 }
 
 // inject emits the code for an injector.
-func (g *gen) inject(pos token.Pos, name string, sig *types.Signature, set *ProviderSet) []error {
+func (g *gen) inject(pos token.Pos, name string, sig *types.Signature, set *ProviderSet, doc *ast.CommentGroup) []error {
 	injectSig, err := funcOutput(sig)
 	if err != nil {
 		return []error{notePosition(g.pkg.Fset.Position(pos),
@@ -367,12 +371,12 @@ func (g *gen) inject(pos token.Pos, name string, sig *types.Signature, set *Prov
 	}
 
 	// Perform one pass to collect all imports, followed by the real pass.
-	injectPass(name, sig, calls, set, &injectorGen{
+	injectPass(name, sig, calls, set, doc, &injectorGen{
 		g:       g,
 		errVar:  disambiguate("err", g.nameInFileScope),
 		discard: true,
 	})
-	injectPass(name, sig, calls, set, &injectorGen{
+	injectPass(name, sig, calls, set, doc, &injectorGen{
 		g:       g,
 		errVar:  disambiguate("err", g.nameInFileScope),
 		discard: false,
@@ -586,13 +590,18 @@ type injectorGen struct {
 
 // injectPass generates an injector given the output from analysis.
 // The sig passed in should be verified.
-func injectPass(name string, sig *types.Signature, calls []call, set *ProviderSet, ig *injectorGen) {
+func injectPass(name string, sig *types.Signature, calls []call, set *ProviderSet, doc *ast.CommentGroup, ig *injectorGen) {
 	params := sig.Params()
 	injectSig, err := funcOutput(sig)
 	if err != nil {
 		// This should be checked by the caller already.
 		panic(err)
 	}
+	if doc != nil {
+		for _, c := range doc.List {
+			ig.p("%s\n", c.Text)
+		}
+	}
 	ig.p("func %s(", name)
 	for i := 0; i < params.Len(); i++ {
 		if i > 0 {
@@ -769,16 +778,6 @@ func (ig *injectorGen) p(format string, args ...interface{}) {
 	ig.g.p(format, args...)
 }
 
-func (ig *injectorGen) writeAST(info *types.Info, node ast.Node) {
-	node = ig.g.rewritePkgRefs(info, node)
-	if ig.discard {
-		return
-	}
-	if err := printer.Fprint(&ig.g.buf, ig.g.pkg.Fset, node); err != nil {
-		panic(err)
-	}
-}
-
 // zeroValue returns the shortest expression that evaluates to the zero
 // value for the given type.
 func zeroValue(t types.Type, qf types.Qualifier) string {
